@@ -2,6 +2,7 @@ import os
 import pwd
 import grp
 import logging
+import platform
 
 logger = logging.getLogger(__name__)
 
@@ -21,8 +22,15 @@ def drop(work_dir, new_uid='nobody', new_gid='nogroup'):
     if os.getuid() != 0:
         return
     if starting_uid == 0:
+
+        #special handling for os x. (getgrname has trouble with gid below 0)
+        if platform.mac_ver()[0]:
+            wanted_gid = -2
+        else:
+            wanted_gid = grp.getgrnam(new_gid)[2]
+
         run_uid = pwd.getpwnam(new_uid)[2]
-        run_gid = grp.getgrnam(new_gid)[2]
+        run_gid = wanted_gid
         try:
             recursive_chown(work_dir, run_uid, run_gid)
         except OSError as e:
